<?php
/* @(#)$KimmoSuominen: dofollow.php,v 1.12 2006/12/24 10:23:06 kim Exp $
 *
 * Copyright (c) 2005 Kimmo Suominen
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer
 *    in the documentation and/or other materials provided with the
 *    distribution.
 * 3. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

/*
Plugin Name: DoFollow
Plugin URI: http://kimmo.suominen.com/sw/dofollow/
Description: Disable the "nofollow" tagging for comments.  Timeout using comment age inspired by <a href="http://bronski.net/">Christoph Rummel</a>.  <strong>Configuration: <a href="options-general.php?page=dofollow.php">Options &raquo; DoFollow</a></strong>.
Author: Kimmo Suominen
Version: 2.2
Author URI: http://kimmo.suominen.com/
*/

if (is_plugin_page()):
    $wppDoFollow->options_page();
else:

class DoFollow
{
    var $ldate = 0;
    var $timeout = 0;

    function DoFollow()
    {
	if ($this->timeout = intval(get_option('dofollow_timeout'))) {
	    $this->ldate = time() - ($this->timeout * 86400);
	} else {
	    // Make it tomorrow, so we don't have to worry about time zones
	    $this->ldate = time() + 86400;
	}

	add_filter('comment_text',
	    array(&$this, 'nofollow_del'), 16);

	add_filter('get_comment_author_link',
	    array(&$this, 'nofollow_del'), 16);

	remove_filter('pre_comment_content', 'wp_rel_nofollow', 15);
	if ($this->timeout)
	    add_filter('pre_comment_content',
		array(&$this, 'nofollow_ins'), 15);

	add_action('admin_menu', array(&$this, 'admin_menu'));
	// Broken in WordPress 1.5
	//add_action('options_page_dofollow', array(&$this, 'options_page'));
    }

    function admin_menu()
    {
	add_options_page(
	    __('DoFollow Options'),
	    __('DoFollow'), 5, basename(__FILE__));
    }

    function options_page()
    {
	if (isset($_POST['Submit'])):
	    update_option('dofollow_timeout',
		intval($_POST['dofollow_timeout']));
?>
<div class="updated">
<p><strong><?php _e('Options saved.') ?></strong></p>
</div>
<?php
	endif;
	if ($this->timeout = intval(get_option('dofollow_timeout'))) {
	    $this->ldate = time() - ($this->timeout * 86400);
	}
?>
<div class="wrap">
<h2><?php echo __('DoFollow Options'); ?></h2>
<form name="dofollow" method="post" action="">
  <input type="hidden" name="action" value="update" />
  <input type="hidden" name="page_options" value="'dofollow_timeout'" />
    <fieldset class="options">
	<legend><?php echo _e('Operating mode'); ?></legend>
	<table cellspacing="2" cellpadding="5" class="editform">
	    <tr valign="baseline">
		<td><?php echo $this->timeout
		    ? sprintf(__('Timeout is set to %s days.'), $this->timeout)
		      . ' '
		      . sprintf(
			__('Nofollow will be removed from comments posted before %s.'),
			date('r (T)', $this->ldate))
		    : __('No timeout is set.  Nofollow will be removed from comments immediately.');
		    ?></td>
	    </tr>
	</table>
    </fieldset>
  <br />
  <fieldset class="options">
    <legend><?php echo __('Nofollow timeout'); ?></legend>
    <table cellspacing="2" cellpadding="5" class="editform">
      <tr valign="baseline">
	<td><?php echo sprintf(
	    __('Remove nofollow from comments older than %s days.'),
	    '<input name="dofollow_timeout" type="text" id="dofollow_timeout"'
	    . ' value="' . $this->timeout . '" size="3" align="right" />');
	?></td>
      </tr>
    </table>
  </fieldset>
  <p class="submit">
      <input type="submit" name="Submit"
	  value="<?php _e('Update Options') ?> &raquo;" />
  </p>
</form>
</div>
<?php
    }

    function nofollow_del($text)
    {
	global $comment;

	if (mysql2date('U', $comment->comment_date) > $this->ldate)
	    return $text;

	$text = preg_replace('|<a (.*)rel=([\'"])nofollow\2( (.+))?>|i',
	    '<a $1$3>', $text);
	$text = preg_replace('|<a (.*)rel=([\'"])nofollow (.+)\2( (.+))?>|i',
	    '<a $1rel=$2$3$2$4>', $text);
	$text = preg_replace('|<a (.*)rel=([\'"])(.+) nofollow\2( (.+))?>|i',
	    '<a $1rel=$2$3$2$4>', $text);
	$text = preg_replace('|<a (.*)rel=([\'"])(.+) nofollow (.+)\2( (.+))>|i',
	    '<a $1rel=$2$3 $4$2$5>', $text);
	return $text;
    }

    function nofollow_ins($text)
    {
	global $comment;

	if (mysql2date('U', $comment->comment_date) > $this->ldate)
	    return wp_rel_nofollow($text);

	return $text;
    }
}

$wppDoFollow =& new DoFollow;

endif; // is_plugin_page()

?>